# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Cloudsave Service."""

__version__ = "3.6.2"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .models_admin_concurrent_record_request import ModelsAdminConcurrentRecordRequest
from .models_bulk_get_game_record_request import ModelsBulkGetGameRecordRequest
from .models_bulk_get_game_record_response import ModelsBulkGetGameRecordResponse
from .models_bulk_get_player_record_response import ModelsBulkGetPlayerRecordResponse
from .models_bulk_get_player_record_size_response import (
    ModelsBulkGetPlayerRecordSizeResponse,
)
from .models_bulk_get_player_records_request import ModelsBulkGetPlayerRecordsRequest
from .models_bulk_user_i_ds_request import ModelsBulkUserIDsRequest
from .models_bulk_user_key_request import ModelsBulkUserKeyRequest
from .models_concurrent_record_request import ModelsConcurrentRecordRequest
from .models_game_record_request import ModelsGameRecordRequest
from .models_game_record_response import ModelsGameRecordResponse
from .models_list_game_record_keys_response import ModelsListGameRecordKeysResponse
from .models_list_player_record_keys_response import ModelsListPlayerRecordKeysResponse
from .models_pagination import ModelsPagination
from .models_player_record_key_info import ModelsPlayerRecordKeyInfo
from .models_player_record_request import ModelsPlayerRecordRequest
from .models_player_record_response import ModelsPlayerRecordResponse
from .models_player_record_size_response import ModelsPlayerRecordSizeResponse
from .models_response_error import ModelsResponseError
from .models_user_key_request import ModelsUserKeyRequest
