# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import LegalReadinessStatusResponse

from ..operations.utility import CheckReadiness


@same_doc_as(CheckReadiness)
def check_readiness(x_additional_headers: Optional[Dict[str, str]] = None, **kwargs):
    """Check Legal Data Readiness (checkReadiness)

    Readiness status defined as at least one legal basePolicy is present and having active basePolicy.
    Other detail info:

      * Required permission : resource="NAMESPACE:{namespace}:LEGAL", action=2 (READ)

    Required Permission(s):
        - NAMESPACE:{namespace}:LEGAL [READ]

    Properties:
        url: /agreement/public/readiness

        method: GET

        tags: ["Utility"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH] or [BEARER_AUTH]

    Responses:
        200: OK - LegalReadinessStatusResponse (successful operation)
    """
    request = CheckReadiness.create()
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(CheckReadiness)
async def check_readiness_async(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Check Legal Data Readiness (checkReadiness)

    Readiness status defined as at least one legal basePolicy is present and having active basePolicy.
    Other detail info:

      * Required permission : resource="NAMESPACE:{namespace}:LEGAL", action=2 (READ)

    Required Permission(s):
        - NAMESPACE:{namespace}:LEGAL [READ]

    Properties:
        url: /agreement/public/readiness

        method: GET

        tags: ["Utility"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH] or [BEARER_AUTH]

    Responses:
        200: OK - LegalReadinessStatusResponse (successful operation)
    """
    request = CheckReadiness.create()
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )
