# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Session Service."""

__version__ = "2.6.9"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_create_configurat_34b9c2 import AdminCreateConfigurationTemplateV1
from .admin_delete_configurat_f38a32 import AdminDeleteConfigurationTemplateV1
from .admin_get_all_configura_f8d91f import AdminGetAllConfigurationTemplatesV1
from .admin_get_configuration_b1005a import AdminGetConfigurationTemplateV1
from .admin_update_configurat_b6ef34 import AdminUpdateConfigurationTemplateV1
