# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Platform Service."""

__version__ = "4.25.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .apply_user_redemption import ApplyUserRedemption
from .bulk_disable_codes import BulkDisableCodes
from .bulk_enable_codes import BulkEnableCodes
from .create_campaign import CreateCampaign
from .create_codes import CreateCodes
from .disable_code import DisableCode
from .download import Download
from .enable_code import EnableCode
from .get_campaign import GetCampaign
from .get_campaign_dynamic import GetCampaignDynamic
from .get_code import GetCode
from .query_campaigns import QueryCampaigns
from .query_codes import QueryCodes
from .query_redeem_history import QueryRedeemHistory
from .update_campaign import UpdateCampaign
