# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Basic Service."""

__version__ = "2.6.1"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .add_country_group import AddCountryGroup
from .delete_country_group import DeleteCountryGroup
from .get_countries import GetCountries
from .get_country_groups import GetCountryGroups
from .get_languages import GetLanguages
from .get_time_zones import GetTimeZones
from .public_get_countries import PublicGetCountries
from .public_get_languages import PublicGetLanguages
from .public_get_time import PublicGetTime
from .public_get_time_zones import PublicGetTimeZones
from .update_country_group import UpdateCountryGroup
