# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Session Browser Service."""

__version__ = ""
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

# session
from .wrappers import add_player_to_session
from .wrappers import add_player_to_session_async
from .wrappers import admin_delete_session
from .wrappers import admin_delete_session_async
from .wrappers import admin_get_session
from .wrappers import admin_get_session_async
from .wrappers import admin_query_session
from .wrappers import admin_query_session_async
from .wrappers import admin_search_sessions_v2
from .wrappers import admin_search_sessions_v2_async
from .wrappers import create_session
from .wrappers import create_session_async
from .wrappers import delete_session
from .wrappers import delete_session_async
from .wrappers import delete_session_local_ds
from .wrappers import delete_session_local_ds_async
from .wrappers import get_active_custom_game_sessions
from .wrappers import get_active_custom_game_sessions_async
from .wrappers import get_active_matchmaking_game_sessions
from .wrappers import get_active_matchmaking_game_sessions_async
from .wrappers import get_recent_player
from .wrappers import get_recent_player_async
from .wrappers import get_session
from .wrappers import get_session_async
from .wrappers import get_session_by_user_i_ds
from .wrappers import get_session_by_user_i_ds_async
from .wrappers import get_session_history_detailed
from .wrappers import get_session_history_detailed_async
from .wrappers import get_total_active_session
from .wrappers import get_total_active_session_async
from .wrappers import join_session
from .wrappers import join_session_async
from .wrappers import remove_player_from_session
from .wrappers import remove_player_from_session_async
from .wrappers import update_session
from .wrappers import update_session_async
from .wrappers import update_settings
from .wrappers import update_settings_async
from .wrappers import user_query_session
from .wrappers import user_query_session_async
